/*
 *  HC12 i/o register locations (9s12dp256)
 *  From Reg9s12.h from documentation package for
 *  EVBPlus/Wytec Co. Dragon12 trainer board.
 *  Translated to C preprocessor syntax
 *  by Louis Bertrand <louis.bertrand@durhamc.on.ca>
 */


#ifndef _REG9S12_H
#define _REG9S12_H


#define porta	(0)	/* port a = address lines a8 - a15 */
#define portb	(1)	/* port b = address lines a0 - a7 */
#define ddra	(2)	/* port a direction register */
#define ddrb	(3)	/* port a direction register */

#define porte	(8)	/* port e = mode,irqandcontrolsignals */
#define ddre	(9)	/* port e direction register */
#define pear	(0xa)	/* port e assignments */
#define mode	(0xb)	/* mode register */
#define pucr	(0xc)	/* port pull-up control register */
#define rdriv	(0xd)	/* port reduced drive control register */
#define ebictl	(0xe)	/* e stretch control */

#define initrm	(0x10)	/* ram location register */
#define initrg	(0x11)	/* register location register */
#define initee	(0x12)	/* eeprom location register */
#define misc	(0x13)	/* miscellaneous mapping control */
#define mtst0	(0x14)	/*  reserved */
#define itcr	(0x15)	/* interrupt test control register */
#define itest	(0x16)	/* interrupt test register */
#define mtst1	(0x17)	/*  reserved */

#define partidh	(0x1a)	/* part id high */
#define partidl	(0x1b)	/* part id low */
#define memsiz0	(0x1c)	/* memory size */
#define memsiz1	(0x1d)	/* memory size */
#define intcr	(0x1e)	/* interrupt control register */
#define hprio	(0x1f)	/* high priority reg */

#define bkpct0	(0x28)	/* break control register */
#define bkpct1	(0x29)	/* break control register */
#define bkp0x	(0x2a)	/*  break 0 index register */
#define bkp0h	(0x2b)	/*  break 0 pointer high */
#define brp0l	(0x2c)	/*  break 0 pointer low */
#define bkp1x	(0x2d)	/*  break 1 index register */
#define bkp1h	(0x2e)	/*  break 1 pointer high */
#define brp1l	(0x2f)	/*  break 1 pointer low */
#define ppage	(0x30)	/* program page register */

#define portk	(0x32)	/* port k data */
#define ddrk	(0x33)	/* port k direction */
#define synr	(0x34)	/*  synthesizer / multiplier register */
#define refdv	(0x35)	/*  reference divider register */
#define ctflg	(0x36)	/*  reserved */
#define crgflg	(0x37)	/*  pll flags register */
#define crgint	(0x38)	/*  pll interrupt register */
#define clksel	(0x39)	/*  clock select register */
#define pllctl	(0x3a)	/*  pll control register */
#define rtictl	(0x3b)	/* real time interrupt control */
#define copctl	(0x3c)	/* watchdog control */
#define forbyp	(0x3d)
#define ctctl	(0x3e)
#define armcop	(0x3f)	/* cop reset register */

#define tios	(0x40)	/* timer input/output select */
#define cforc	(0x41)	/* timer compare force */
#define oc7m	(0x42)	/* timer output compare 7 mask */
#define oc7d	(0x43)	/* timer output compare 7 data */
#define tcnt	(0x44)	/* timer counter register hi */
/* tcnt:          equ $45 ;timer counter register lo */
#define tscr	(0x46)	/* timer system control register */
#define ttov	(0x47)	/* reserved */
#define tctl1	(0x48)	/* timer control register 1 */
#define tctl2	(0x49)	/* timer control register 2 */
#define tctl3	(0x4a)	/* timer control register 3 */
#define tctl4	(0x4b)	/* timer control register 4 */
#define tmsk1	(0x4c)	/* timer interrupt mask 1 */
#define tmsk2	(0x4d)	/* timer interrupt mask 2 */
#define tflg1	(0x4e)	/* timer flags 1 */
#define tflg2	(0x4f)	/* timer flags 2 */
#define tc0	(0x50)	/* timer capture/compare register 0 */
#define tc1	(0x52)	/* timer capture/compare register 1 */
#define tc2	(0x54)	/* timer capture/compare register 2 */
#define tc3	(0x56)	/* timer capture/compare register 3 */
#define tc4	(0x58)	/* timer capture/compare register 4 */
#define tc5	(0x5a)	/* timer capture/compare register 5 */
#define tc6	(0x5c)	/* timer capture/compare register 6 */
#define tc7	(0x5e)	/* timer capture/compare register 7 */
#define pactl	(0x60)	/* pulse accumulator controls */
#define paflg	(0x61)	/* pulse accumulator flags */
#define pacn3	(0x62)	/* pulse accumulator counter 3 */
#define pacn2	(0x63)	/* pulse accumulator counter 2 */
#define pacn1	(0x64)	/* pulse accumulator counter 1 */
#define pacn0	(0x65)	/* pulse accumulator counter 0 */
#define mcctl	(0x66)	/* modulus down conunter control */
#define mcflg	(0x67)	/* down counter flags */
#define icpar	(0x68)	/* input pulse accumulator control */
#define dlyct	(0x69)	/* delay count to down counter */
#define icovw	(0x6a)	/* input control overwrite register */
#define icsys	(0x6b)	/* input control system control */

#define timtst	(0x6d)	/* timer test register */

#define pbctl	(0x70)	/*  pulse accumulator b control */
#define pbflg	(0x71)	/*  pulse accumulator b flags */
#define pa3h	(0x72)	/*  pulse accumulator holding register 3 */
#define pa2h	(0x73)	/*  pulse accumulator holding register 2 */
#define pa1h	(0x74)	/*  pulse accumulator holding register 1 */
#define pa0h	(0x75)	/*  pulse accumulator holding register 0 */
#define mccnt	(0x76)	/*  modulus down counter register */
/* mccntl:        equ $77 ; low byte */
#define tcoh	(0x78)	/*  capture 0 holding register */
#define tc1h	(0x7a)	/*  capture 1 holding register */
#define tc2h	(0x7c)	/*  capture 2 holding register */
#define tc3h	(0x7e)	/*  capture 3 holding register */

#define atd0ctl0	(0x80)	/* adc control 0 (reserved) */
#define atd0ctl1	(0x81)	/* adc control 1 (reserved) */
#define atd0ctl2	(0x82)	/* adc control 2 */
#define atd0ctl3	(0x83)	/* adc control 3 */
#define atd0ctl4	(0x84)	/* adc control 4 */
#define atd0ctl5	(0x85)	/* adc control 5 */
#define atd0stat	(0x86)	/* adc status register hi */
/* atd0stat       equ $87 ;adc status register lo */
#define atd0test	(0x88)	/* adc test (reserved) */
/* atd0test       equ $89 ; */

#define atd0dien	(0x8d)

#define portad	(0x8f)	/* port adc = input only */
#define adr00h	(0x90)	/* adc result 0 register */
#define adr01h	(0x92)	/* adc result 1 register */
#define adr02h	(0x94)	/* adc result 2 register */
#define adr03h	(0x96)	/* adc result 3 register */
#define adr04h	(0x98)	/* adc result 4 register */
#define adr05h	(0x9a)	/* adc result 5 register */
#define adr06h	(0x9c)	/* adc result 6 register */
#define adr07h	(0x9e)	/* adc result 7 register */

#define pwme	(0xa0)	/* pwm enable */
#define pwmpol	(0xa1)	/* pwm polarity */
#define pwmclk	(0xa2)	/* pwm clock select register */
#define pwmprclk	(0xa3)	/* pwm prescale clock select register */
#define pwmcae	(0xa4)	/* pwm center align select register */
#define pwmctl	(0xa5)	/* pwm control register */
#define pwmtst	(0xa6)	/* reserved */
#define pwmprsc	(0xa7)	/* reserved */
#define pwmscla	(0xa8)	/* pwm scale a */
#define pwmsclb	(0xa9)	/* pwm scale b */
#define pwmscnta	(0xaa)	/* reserved */
#define pwmscntb	(0xab)	/* reserved */
#define pwmcnt0	(0xac)	/* pwm channel 0 counter */
#define pwmcnt1	(0xad)	/* pwm channel 1 counter */
#define pwmcnt2	(0xae)	/* pwm channel 2 counter */
#define pwmcnt3	(0xaf)	/* pwm channel 3 counter */
#define pwmcnt4	(0xb0)	/* pwm channel 4 counter */
#define pwmcnt5	(0xb1)	/* pwm channel 5 counter */
#define pwmcnt6	(0xb2)	/* pwm channel 6 counter */
#define pwmcnt7	(0xb3)	/* pwm channel 7 counter */
#define pwmper0	(0xb4)	/* pwm channel 0 period */
#define pwmper1	(0xb5)	/* pwm channel 1 period */
#define pwmper2	(0xb6)	/* pwm channel 2 period */
#define pwmper3	(0xb7)	/* pwm channel 3 period */
#define pwmper4	(0xb8)	/* pwm channel 4 period */
#define pwmper5	(0xb9)	/* pwm channel 5 period */
#define pwmper6	(0xba)	/* pwm channel 6 period */
#define pwmper7	(0xbb)	/* pwm channel 7 period */
#define pwmdty0	(0xbc)	/* pwm channel 0 duty cycle */
#define pwmdty1	(0xbd)	/* pwm channel 1 duty cycle */
#define pwmdty2	(0xbe)	/* pwm channel 2 duty cycle */
#define pwmdty3	(0xbf)	/* pwm channel 3 duty cycle */
#define pwmdty4	(0xc0)	/* pwm channel 0 duty cycle */
#define pwmdty5	(0xc1)	/* pwm channel 1 duty cycle */
#define pwmdty6	(0xc2)	/* pwm channel 2 duty cycle */
#define pwmdty7	(0xc3)	/* pwm channel 3 duty cycle */
#define pwmsdn	(0xc4)	/* pwm shutdown register */

#define sc0bdh	(0xc8)	/* sci 0 baud reg hi byte */
#define sc0bdl	(0xc9)	/* sci 0 baud reg lo byte */
#define sc0cr1	(0xca)	/* sci 0 control1 reg */
#define sc0cr2	(0xcb)	/* sci 0 control2 reg */
#define sc0sr1	(0xcc)	/* sci 0 status reg 1 */
#define sc0sr2	(0xcd)	/* sci 0 status reg 2 */
#define sc0drh	(0xce)	/* sci 0 data reg hi */
#define sc0drl	(0xcf)	/* sci 0 data reg lo */
#define sc1bdh	(0xd0)	/* sci 1 baud reg hi byte */
#define sc1bdl	(0xd1)	/* sci 1 baud reg lo byte */
#define sc1cr1	(0xd2)	/* sci 1 control1 reg */
#define sc1cr2	(0xd3)	/* sci 1 control2 reg */
#define sc1sr1	(0xd4)	/* sci 1 status reg 1 */
#define sc1sr2	(0xd5)	/* sci 1 status reg 2 */
#define sc1drh	(0xd6)	/* sci 1 data reg hi */
#define sc1drl	(0xd7)	/* sci 1 data reg lo */
#define spi0cr1	(0xd8)	/* spi 0 control1 reg */
#define spi0cr2	(0xd9)	/* spi 0 control2 reg */
#define spi0br	(0xda)	/* spi 0 baud reg */
#define spi0sr	(0xdb)	/* spi 0 status reg hi */

#define sp0dr	(0xdd)	/* spi 0 data reg */

#define ibad	(0xe0)	/* i2c bus address register */
#define ibfd	(0xe1)	/* i2c bus frequency divider */
#define ibcr	(0xe2)	/* i2c bus control register */
#define ibsr	(0xe3)	/* i2c bus status register */
#define ibdr	(0xe4)	/* i2c bus message data register */

#define dlcbcr1	(0xe8)	/* bdlc control regsiter 1 */
#define dlcbsvr	(0xe9)	/* bdlc state vector register */
#define dlcbcr2	(0xea)	/* bdlc control register 2 */
#define dlcbdr	(0xeb)	/* bdlc data register */
#define dlcbard	(0xec)	/* bdlc analog delay register */
#define dlcbrsr	(0xed)	/* bdlc rate select register */
#define dlcscr	(0xee)	/* bdlc control register */
#define dlcbstat	(0xef)	/* bdlc status register */
#define spi1cr1	(0xf0)	/* spi 1 control1 reg */
#define spi1cr2	(0xf1)	/* spi 1 control2 reg */
#define spi1br	(0xf2)	/* spi 1 baud reg */
#define spi1sr	(0xf3)	/* spi 1 status reg hi */

#define sp1dr	(0xf5)	/* spi 1 data reg */

#define spi2cr1	(0xf8)	/* spi 2 control1 reg */
#define spi2cr2	(0xf9)	/* spi 2 control2 reg */
#define spi2br	(0xfa)	/* spi 2 baud reg */
#define spi2sr	(0xfb)	/* spi 2 status reg hi */

#define sp2dr	(0xfd)	/* spi 2 data reg */

#define fclkdiv	(0x100)	/* flash clock divider */
#define fsec	(0x101)	/* flash security register */

#define fcnfg	(0x103)	/* flash configuration register */
#define fprot	(0x104)	/* flash protection register */
#define fstat	(0x105)	/* flash status register */
#define fcmd	(0x106)	/* flash command register */

#define eclkdiv	(0x110)	/* eeprom clock divider */

#define ecnfg	(0x113)	/* eeprom configuration register */
#define eprot	(0x114)	/* eeprom protection register */
#define estat	(0x115)	/* eeprom status register */
#define ecmd	(0x116)	/* eeprom command register */

#define atd1ctl0	(0x120)	/* adc1 control 0 (reserved) */
#define atd1ctl1	(0x121)	/* adc1 control 1 (reserved) */
#define atd1ctl2	(0x122)	/* adc1 control 2 */
#define atd1ctl3	(0x123)	/* adc1 control 3 */
#define atd1ctl4	(0x124)	/* adc1 control 4 */
#define atd1ctl5	(0x125)	/* adc1 control 5 */
#define atd1stat	(0x126)	/* adc1 status register hi */
/* atd1stat       equ $127 ;adc1 status register lo */
#define atd1test	(0x128)	/* adc1 test (reserved) */
/* atd1test       equ $129 ; */

#define atddien	(0x12d)	/* adc1 input enable register */

#define portad1	(0x12f)	/* port adc1 = input only */
#define adr10h	(0x130)	/* adc1 result 0 register */
#define adr11h	(0x132)	/* adc1 result 1 register */
#define adr12h	(0x134)	/* adc1 result 2 register */
#define adr13h	(0x136)	/* adc1 result 3 register */
#define adr14h	(0x138)	/* adc1 result 4 register */
#define adr15h	(0x13a)	/* adc1 result 5 register */
#define adr16h	(0x13c)	/* adc1 result 6 register */
#define adr17h	(0x13e)	/* adc1 result 7 register */
#define can0ctl0	(0x140)	/* can0 control register 0 */
#define can0ctl1	(0x141)	/* can0 control register 1 */
#define can0btr0	(0x142)	/* can0 bus timing register 0 */
#define can0btr1	(0x143)	/* can0 bus timing register 1 */
#define can0rflg	(0x144)	/* can0 receiver flags */
#define can0rier	(0x145)	/* can0 receiver interrupt enables */
#define can0tflg	(0x146)	/* can0 transmit flags */
#define can0tier	(0x147)	/* can0 transmit interrupt enables */
#define can0tarq	(0x148)	/* can0 transmit message abort control */
#define can0taak	(0x149)	/* can0 transmit message abort status */
#define can0tbel	(0x14a)	/* can0 transmit buffer select */
#define can0idac	(0x14b)	/* can0 identfier acceptance control */

#define can0rerr	(0x14e)	/* can0 receive error counter */
#define can0terr	(0x14f)	/* can0 transmit error counter */
#define can0ida0	(0x150)	/* can0 identifier acceptance register 0 */
#define can0ida1	(0x151)	/* can0 identifier acceptance register 1 */
#define can0ida2	(0x152)	/* can0 identifier acceptance register 2 */
#define can0ida3	(0x153)	/* can0 identifier acceptance register 3 */
#define can0idm0	(0x154)	/* can0 identifier mask register 0 */
#define can0idm1	(0x155)	/* can0 identifier mask register 1 */
#define can0idm2	(0x156)	/* can0 identifier mask register 2 */
#define can0idm3	(0x157)	/* can0 identifier mask register 3 */
#define can0ida4	(0x158)	/* can0 identifier acceptance register 4 */
#define can0ida5	(0x159)	/* can0 identifier acceptance register 5 */
#define can0ida6	(0x15a)	/* can0 identifier acceptance register 6 */
#define can0ida7	(0x15b)	/* can0 identifier acceptance register 7 */
#define can0idm4	(0x15c)	/* can0 identifier mask register 4 */
#define can0idm5	(0x15d)	/* can0 identifier mask register 5 */
#define can0idm6	(0x15e)	/* can0 identifier mask register 6 */
#define can0idm7	(0x15f)	/* can0 identifier mask register 7 */
#define can0rxfg	(0x160)	/* can0 rx foreground buffer thru +$16f */
#define can0txfg	(0x170)	/* can0 tx foreground buffer thru +$17f */

#define can1ctl0	(0x180)	/* can1 control register 0 */
#define can1ctl1	(0x181)	/* can1 control register 1 */
#define can1btr0	(0x182)	/* can1 bus timing register 0 */
#define can1btr1	(0x183)	/* can1 bus timing register 1 */
#define can1rflg	(0x184)	/* can1 receiver flags */
#define can1rier	(0x185)	/* can1 receiver interrupt enables */
#define can1tflg	(0x186)	/* can1 transmit flags */
#define can1tier	(0x187)	/* can1 transmit interrupt enables */
#define can1tarq	(0x188)	/* can1 transmit message abort control */
#define can1taak	(0x189)	/* can1 transmit message abort status */
#define can1tbel	(0x18a)	/* can1 transmit buffer select */
#define can1idac	(0x18b)	/* can1 identfier acceptance control */

#define can1rerr	(0x18e)	/* can1 receive error counter */
#define can1terr	(0x18f)	/* can1 transmit error counter */
#define can1ida0	(0x190)	/* can1 identifier acceptance register 0 */
#define can1ida1	(0x191)	/* can1 identifier acceptance register 1 */
#define can1ida2	(0x192)	/* can1 identifier acceptance register 2 */
#define can1ida3	(0x193)	/* can1 identifier acceptance register 3 */
#define can1idm0	(0x194)	/* can1 identifier mask register 0 */
#define can1idm1	(0x195)	/* can1 identifier mask register 1 */
#define can1idm2	(0x196)	/* can1 identifier mask register 2 */
#define can1idm3	(0x197)	/* can1 identifier mask register 3 */
#define can1ida4	(0x198)	/* can1 identifier acceptance register 4 */
#define can1ida5	(0x199)	/* can1 identifier acceptance register 5 */
#define can1ida6	(0x19a)	/* can1 identifier acceptance register 6 */
#define can1ida7	(0x19b)	/* can1 identifier acceptance register 7 */
#define can1idm4	(0x19c)	/* can1 identifier mask register 4 */
#define can1idm5	(0x19d)	/* can1 identifier mask register 5 */
#define can1idm6	(0x19e)	/* can1 identifier mask register 6 */
#define can1idm7	(0x19f)	/* can1 identifier mask register 7 */
#define can1rxfg	(0x1a0)	/* can1 rx foreground buffer thru +$1af */
#define can1txfg	(0x1b0)	/* can1 tx foreground buffer thru +$1bf */

#define can2ctl0	(0x1c0)	/* can2 control register 0 */
#define can2ctl1	(0x1c1)	/* can2 control register 1 */
#define can2btr0	(0x1c2)	/* can2 bus timing register 0 */
#define can2btr1	(0x1c3)	/* can2 bus timing register 1 */
#define can2rflg	(0x1c4)	/* can2 receiver flags */
#define can2rier	(0x1c5)	/* can2 receiver interrupt enables */
#define can2tflg	(0x1c6)	/* can2 transmit flags */
#define can2tier	(0x1c7)	/* can2 transmit interrupt enables */
#define can2tarq	(0x1c8)	/* can2 transmit message abort control */
#define can2taak	(0x1c9)	/* can2 transmit message abort status */
#define can2tbel	(0x1ca)	/* can2 transmit buffer select */
#define can2idac	(0x1cb)	/* can2 identfier acceptance control */

#define can2rerr	(0x1ce)	/* can2 receive error counter */
#define can2terr	(0x1cf)	/* can2 transmit error counter */
#define can2ida0	(0x1d0)	/* can2 identifier acceptance register 0 */
#define can2ida1	(0x1d1)	/* can2 identifier acceptance register 1 */
#define can2ida2	(0x1d2)	/* can2 identifier acceptance register 2 */
#define can2ida3	(0x1d3)	/* can2 identifier acceptance register 3 */
#define can2idm0	(0x1d4)	/* can2 identifier mask register 0 */
#define can2idm1	(0x1d5)	/* can2 identifier mask register 1 */
#define can2idm2	(0x1d6)	/* can2 identifier mask register 2 */
#define can2idm3	(0x1d7)	/* can2 identifier mask register 3 */
#define can2ida4	(0x1d8)	/* can2 identifier acceptance register 4 */
#define can2ida5	(0x1d9)	/* can2 identifier acceptance register 5 */
#define can2ida6	(0x1da)	/* can2 identifier acceptance register 6 */
#define can2ida7	(0x1db)	/* can2 identifier acceptance register 7 */
#define can2idm4	(0x1dc)	/* can2 identifier mask register 4 */
#define can2idm5	(0x1dd)	/* can2 identifier mask register 5 */
#define can2idm6	(0x1de)	/* can2 identifier mask register 6 */
#define can2idm7	(0x1df)	/* can2 identifier mask register 7 */
#define can2rxfg	(0x1e0)	/* can2 rx foreground buffer thru +$1ef */
#define can2txfg	(0x1f0)	/* can2 tx foreground buffer thru +$1ff */

#define can3ctl0	(0x200)	/* can3 control register 0 */
#define can3ctl1	(0x201)	/* can3 control register 1 */
#define can3btr0	(0x202)	/* can3 bus timing register 0 */
#define can3btr1	(0x203)	/* can3 bus timing register 1 */
#define can3rflg	(0x204)	/* can3 receiver flags */
#define can3rier	(0x205)	/* can3 receiver interrupt enables */
#define can3tflg	(0x206)	/* can3 transmit flags */
#define can3tier	(0x207)	/* can3 transmit interrupt enables */
#define can3tarq	(0x208)	/* can3 transmit message abort control */
#define can3taak	(0x209)	/* can3 transmit message abort status */
#define can3tbel	(0x20a)	/* can3 transmit buffer select */
#define can3idac	(0x20b)	/* can3 identfier acceptance control */

#define can3rerr	(0x20e)	/* can3 receive error counter */
#define can3terr	(0x20f)	/* can3 transmit error counter */
#define can3ida0	(0x210)	/* can3 identifier acceptance register 0 */
#define can3ida1	(0x211)	/* can3 identifier acceptance register 1 */
#define can3ida2	(0x212)	/* can3 identifier acceptance register 2 */
#define can3ida3	(0x213)	/* can3 identifier acceptance register 3 */
#define can3idm0	(0x214)	/* can3 identifier mask register 0 */
#define can3idm1	(0x215)	/* can3 identifier mask register 1 */
#define can3idm2	(0x216)	/* can3 identifier mask register 2 */
#define can3idm3	(0x217)	/* can3 identifier mask register 3 */
#define can3ida4	(0x218)	/* can3 identifier acceptance register 4 */
#define can3ida5	(0x219)	/* can3 identifier acceptance register 5 */
#define can3ida6	(0x21a)	/* can3 identifier acceptance register 6 */
#define can3ida7	(0x21b)	/* can3 identifier acceptance register 7 */
#define can3idm4	(0x21c)	/* can3 identifier mask register 4 */
#define can3idm5	(0x21d)	/* can3 identifier mask register 5 */
#define can3idm6	(0x21e)	/* can3 identifier mask register 6 */
#define can3idm7	(0x21f)	/* can3 identifier mask register 7 */
#define can3rxfg	(0x220)	/* can3 rx foreground buffer thru +$22f */
#define can3txfg	(0x230)	/* can3 tx foreground buffer thru +$23f */

#define ptt	(0x240)	/* portt data register */
#define ptit	(0x241)	/* portt input register */
#define ddrt	(0x242)	/* portt direction register */
#define rdrt	(0x243)	/* portt reduced drive register */
#define pert	(0x244)	/* portt pull device enable */
#define ppst	(0x245)	/* portt pull polarity select */

#define pts	(0x248)	/* ports data register */
#define ptis	(0x249)	/* ports input register */
#define ddrs	(0x24a)	/* ports direction register */
#define rdrs	(0x24b)	/* ports reduced drive register */
#define pers	(0x24c)	/* ports pull device enable */
#define ppss	(0x24d)	/* ports pull polarity select */
#define woms	(0x24e)	/* ports wired or mode register */

#define ptm	(0x250)	/* portm data register */
#define ptim	(0x251)	/* portm input register */
#define ddrm	(0x252)	/* portm direction register */
#define rdrm	(0x253)	/* portm reduced drive register */
#define perm	(0x254)	/* portm pull device enable */
#define ppsm	(0x255)	/* portm pull polarity select */
#define womm	(0x256)	/* portm wired or mode register */
#define modrr	(0x257)	/* portm module routing register */
#define ptp	(0x258)	/* portp data register */
#define ptip	(0x259)	/* portp input register */
#define ddrp	(0x25a)	/* portp direction register */
#define rdrp	(0x25b)	/* portp reduced drive register */
#define perp	(0x25c)	/* portp pull device enable */
#define ppsp	(0x25d)	/* portp pull polarity select */
#define piep	(0x25e)	/* portp interrupt enable register */
#define pifp	(0x25f)	/* portp interrupt flag register */
#define pth	(0x260)	/* porth data register */
#define ptih	(0x261)	/* porth input register */
#define ddrh	(0x262)	/* porth direction register */
#define rdrh	(0x263)	/* porth reduced drive register */
#define perh	(0x264)	/* porth pull device enable */
#define ppsh	(0x265)	/* porth pull polarity select */
#define pieh	(0x266)	/* porth interrupt enable register */
#define pifh	(0x267)	/* porth interrupt flag register */
#define ptj	(0x268)	/* portp data register */
#define ptij	(0x269)	/* portp input register */
#define ddrj	(0x26a)	/* portp direction register */
#define rdrj	(0x26b)	/* portp reduced drive register */
#define perj	(0x26c)	/* portp pull device enable */
#define ppsj	(0x26d)	/* portp pull polarity select */
#define piej	(0x26e)	/* portp interrupt enable register */
#define pifj	(0x26f)	/* portp interrupt flag register */

#define can4ctl0	(0x280)	/* can4 control register 0 */
#define can4ctl1	(0x281)	/* can4 control register 1 */
#define can4btr0	(0x282)	/* can4 bus timing register 0 */
#define can4btr1	(0x283)	/* can4 bus timing register 1 */
#define can4rflg	(0x284)	/* can4 receiver flags */
#define can4rier	(0x285)	/* can4 receiver interrupt enables */
#define can4tflg	(0x286)	/* can4 transmit flags */
#define can4tier	(0x287)	/* can4 transmit interrupt enables */
#define can4tarq	(0x288)	/* can4 transmit message abort control */
#define can4taak	(0x289)	/* can4 transmit message abort status */
#define can4tbel	(0x28a)	/* can4 transmit buffer select */
#define can4idac	(0x28b)	/* can4 identfier acceptance control */

#define can4rerr	(0x28e)	/* can4 receive error counter */
#define can4terr	(0x28f)	/* can4 transmit error counter */
#define can4ida0	(0x290)	/* can4 identifier acceptance register 0 */
#define can4ida1	(0x291)	/* can4 identifier acceptance register 1 */
#define can4ida2	(0x292)	/* can4 identifier acceptance register 2 */
#define can4ida3	(0x293)	/* can4 identifier acceptance register 3 */
#define can4idm0	(0x294)	/* can4 identifier mask register 0 */
#define can4idm1	(0x295)	/* can4 identifier mask register 1 */
#define can4idm2	(0x296)	/* can4 identifier mask register 2 */
#define can4idm3	(0x297)	/* can4 identifier mask register 3 */
#define can4ida4	(0x298)	/* can4 identifier acceptance register 4 */
#define can4ida5	(0x299)	/* can4 identifier acceptance register 5 */
#define can4ida6	(0x29a)	/* can4 identifier acceptance register 6 */
#define can4ida7	(0x29b)	/* can4 identifier acceptance register 7 */
#define can4idm4	(0x29c)	/* can4 identifier mask register 4 */
#define can4idm5	(0x29d)	/* can4 identifier mask register 5 */
#define can4idm6	(0x29e)	/* can4 identifier mask register 6 */
#define can4idm7	(0x29f)	/* can4 identifier mask register 7 */
#define can4rxfg	(0x2a0)	/* can4 rx foreground buffer thru +$2af */
#define can4txfg	(0x2b0)	/* can4 tx foreground buffer thru +$2bf */

#endif

/*  end registers */
